@@ -42,7 +42,10 @@ def send_tron(addresses, output_folder):
                     index = 0
                     contract_name = code['name']
                     while os.path.exists(contract_folder + "//" + contract_name):
-                        contract_name = code['name'].split('.')[0] + "_{}".format(index) + ".sol"
+                        if contract_name.find("_")!= -1:
+                            contract_name = code['name'].split('_')[0] + "_{}".format(index) + ".sol"
+                        else:
+                            contract_name = code['name'].split('.')[0] + "_{}".format(index) + ".sol"
                         index += 1
                     make_dir(os.path.split(contract_folder + "//" + contract_name)[0])
                     with open(contract_folder + "//" + contract_name, "w+", encoding='utf-8') as fw:
@@ -97,7 +100,10 @@ def send_okex(addresses, output_folder, apikey, network):
                     index = 0
                     contract_name = code['name'] + ".sol"
                     while os.path.exists(contract_folder + "//" + contract_name):
-                        contract_name = code['name'].split('.')[0] + "_{}".format(index) + ".sol"
+                        if contract_name.find("_")!= -1:
+                            contract_name = code['name'].split('_')[0] + "_{}".format(index) + ".sol"
+                        else:
+                            contract_name = code['name'].split('.')[0] + "_{}".format(index) + ".sol"
                         index += 1
                     make_dir(os.path.split(contract_folder + "//" + contract_name)[0])
                     with open(contract_folder + "//" + contract_name, "w+", encoding='utf-8') as fw:
@@ -138,7 +144,10 @@ def send_klaytn(addresses, output_folder, network):
             contract_folder = code['contractName'] if output_folder == "" else output_folder
             index = 0
             while os.path.exists(contract_folder + "//" + contract_name):
-                contract_name = code['contractName'].split('.')[0] + "_{}".format(index) + ".sol"
+                if contract_name.find("_")!= -1:
+                    contract_name = code['contractName'].split('_')[0] + "_{}".format(index) + ".sol"
+                else:
+                    contract_name = code['contractName'].split('.')[0] + "_{}".format(index) + ".sol"
                 index += 1
             make_dir(os.path.split(contract_folder + "//" + contract_name)[0])
             with open(contract_folder + "//" + contract_name, "w+", encoding='utf-8') as fw:
@@ -193,7 +202,10 @@ def send_ronin(addresses, output_folder, network):
             sub_index = 0
             for code in ronin_req['result']:
                 while os.path.exists(contract_folder + "//" + contract_name):
-                    contract_name = code['name'].split('.')[0] + "_{}".format(index) + ".sol"
+                    if contract_name.find("_")!= -1:
+                        contract_name = contract_name.split('_')[0] + "_{}".format(index) + ".sol"
+                    else:
+                        contract_name = contract_name.split('.')[0] + "_{}".format(index) + ".sol"
                     index += 1
                 make_dir(os.path.split(contract_folder + "//" + contract_name)[0])
                 with open(contract_folder + "//" + contract_name, "w+", encoding='utf-8') as fw:
@@ -237,7 +249,10 @@ def send_zksync_era(addresses, output_folder, network):
             sub_index = 0
             for contract_name in zksync_req['request']['sourceCode']['sources'].keys():
                 while os.path.exists(contract_folder + "//" + contract_name):
-                    contract_name = contract_name.split('.')[0] + "_{}".format(index) + ".sol"
+                    if contract_name.find("_")!= -1:
+                        contract_name = contract_name.split('_')[0] + "_{}".format(index) + ".sol"
+                    else:
+                        contract_name = contract_name.split('.')[0] + "_{}".format(index) + ".sol"
                     index += 1
                 make_dir(os.path.split(contract_folder + "//" + contract_name)[0])
                 with open(contract_folder + "//" + contract_name, "w+", encoding='utf-8') as fw:
@@ -263,6 +278,9 @@ def send_request(addresses, output_folder, network):
             'user-agent': USER_AGENT
         }
         for address in addresses:
+            if address in deal_addresses:
+                continue
+            deal_addresses.append(address)
             output_data = ""
             real_url = req_url[network] + address + "&apikey=" + get_key(network)
             req = common_requests(real_url, proxies, headers)
@@ -301,9 +319,12 @@ def export_result(result, output_folder, network, address):
             else:
                 source_code = json.loads(source_code)
             for key in source_code.keys():
-                contract_name = key + contract_suffix
+                contract_name = key + contract_suffix if key.find(contract_suffix) == -1 else key
                 while os.path.exists(contract_folder + "//" + contract_name):
-                    contract_name = key.split(contract_suffix)[0] + "_{}".format(index) + contract_suffix
+                    if contract_name.find("_")!= -1:
+                        contract_name = contract_name.split('_')[0] + "_{}".format(index) + ".sol"
+                    else:
+                        contract_name = contract_name.split('.')[0] + "_{}".format(index) + ".sol"
                     index += 1
                 index = 0
                 make_dir(os.path.split(contract_folder + "//" + contract_name)[0])
@@ -316,10 +337,12 @@ def export_result(result, output_folder, network, address):
             if contract_name == "":
                 return
             contract_folder = contract_name if output_folder == "" else output_folder
-            make_dir(contract_folder)
-            contract_name = contract_name + contract_suffix
+            contract_name = contract_name + contract_suffix if contract_name.find(contract_suffix) == -1 else contract_name
             while os.path.exists(contract_folder + "//" + contract_name):
-                contract_name = result['ContractName'] + "_{}".format(index) + contract_suffix
+                if contract_name.find("_")!= -1:
+                        contract_name = contract_name.split('_')[0] + "_{}".format(index) + ".sol"
+                else:
+                    contract_name = contract_name.split('.')[0] + "_{}".format(index) + ".sol"
                 index += 1
             make_dir(os.path.split(contract_folder + "//" + contract_name)[0])
             with open(contract_folder + "//" + contract_name, "w+", encoding='utf-8') as fw:
